import * as pulumi from "@pulumi/pulumi";
export declare class Role extends pulumi.CustomResource {
    /**
     * Get an existing Role resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RoleState, opts?: pulumi.CustomResourceOptions): Role;
    /**
     * Returns true if the given object is an instance of Role.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Role;
    /**
     * Defines the role to switch to at login via [`SET ROLE`](https://www.postgresql.org/docs/current/sql-set-role.html).
     */
    readonly assumeRole: pulumi.Output<string | undefined>;
    /**
     * Defines whether a role bypasses every
     * row-level security (RLS) policy.  Default value is `false`.
     */
    readonly bypassRowLevelSecurity: pulumi.Output<boolean | undefined>;
    /**
     * If this role can log in, this specifies how
     * many concurrent connections the role can establish. `-1` (the default) means no
     * limit.
     */
    readonly connectionLimit: pulumi.Output<number | undefined>;
    /**
     * Defines a role's ability to execute `CREATE
     * DATABASE`.  Default value is `false`.
     */
    readonly createDatabase: pulumi.Output<boolean | undefined>;
    /**
     * Defines a role's ability to execute `CREATE ROLE`.
     * A role with this privilege can also alter and drop other roles.  Default value
     * is `false`.
     */
    readonly createRole: pulumi.Output<boolean | undefined>;
    /**
     * @deprecated Rename PostgreSQL role resource attribute "encrypted" to "encryptedPassword"
     */
    readonly encrypted: pulumi.Output<string | undefined>;
    /**
     * Defines whether the password is stored
     * encrypted in the system catalogs.  Default value is `true`.  NOTE: this value
     * is always set (to the conservative and safe value), but may interfere with the
     * behavior of
     * [PostgreSQL's `passwordEncryption` setting](https://www.postgresql.org/docs/current/static/runtime-config-connection.html#GUC-PASSWORD-ENCRYPTION).
     */
    readonly encryptedPassword: pulumi.Output<boolean | undefined>;
    /**
     * Terminate any session with an open transaction that has been idle for longer than the specified duration in milliseconds
     */
    readonly idleInTransactionSessionTimeout: pulumi.Output<number | undefined>;
    /**
     * Defines whether a role "inherits" the privileges of
     * roles it is a member of.  Default value is `true`.
     */
    readonly inherit: pulumi.Output<boolean | undefined>;
    /**
     * Defines whether role is allowed to log in.  Roles without
     * this attribute are useful for managing database privileges, but are not users
     * in the usual sense of the word.  Default value is `false`.
     */
    readonly login: pulumi.Output<boolean | undefined>;
    /**
     * The name of the role. Must be unique on the PostgreSQL
     * server instance where it is configured.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Sets the role's password. A password is only of use
     * for roles having the `login` attribute set to true.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * Defines whether a role is allowed to initiate
     * streaming replication or put the system in and out of backup mode.  Default
     * value is `false`
     */
    readonly replication: pulumi.Output<boolean | undefined>;
    /**
     * Defines list of roles which will be granted to this new role.
     */
    readonly roles: pulumi.Output<string[] | undefined>;
    /**
     * Alters the search path of this new role. Note that
     * due to limitations in the implementation, values cannot contain the substring
     * `", "`.
     */
    readonly searchPaths: pulumi.Output<string[] | undefined>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, the
     * [cleanup of ownership of objects](https://www.postgresql.org/docs/current/static/role-removal.html)
     * in each of the respective databases must occur before the ROLE can be dropped
     * from the catalog.  Set this option to true when there are multiple databases
     * in a PostgreSQL cluster using the same PostgreSQL ROLE for object ownership.
     * This is the third and final step taken when removing a ROLE from a database.
     */
    readonly skipDropRole: pulumi.Output<boolean | undefined>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, a
     * [`REASSIGN OWNED`](https://www.postgresql.org/docs/current/static/sql-reassign-owned.html) in
     * must be executed on each of the respective databases before the `DROP ROLE`
     * can be executed to dropped the ROLE from the catalog.  This is the first and
     * second steps taken when removing a ROLE from a database (the second step being
     * an implicit
     * [`DROP OWNED`](https://www.postgresql.org/docs/current/static/sql-drop-owned.html)).
     */
    readonly skipReassignOwned: pulumi.Output<boolean | undefined>;
    /**
     * Defines [`statementTimeout`](https://www.postgresql.org/docs/current/runtime-config-client.html#RUNTIME-CONFIG-CLIENT-STATEMENT) setting for this role which allows to abort any statement that takes more than the specified amount of time.
     */
    readonly statementTimeout: pulumi.Output<number | undefined>;
    /**
     * Defines whether the role is a "superuser", and
     * therefore can override all access restrictions within the database.  Default
     * value is `false`.
     */
    readonly superuser: pulumi.Output<boolean | undefined>;
    /**
     * Defines the date and time after which the role's
     * password is no longer valid.  Established connections past this `validTime`
     * will have to be manually terminated.  This value corresponds to a PostgreSQL
     * datetime. If omitted or the magic value `NULL` is used, `validUntil` will be
     * set to `infinity`.  Default is `NULL`, therefore `infinity`.
     */
    readonly validUntil: pulumi.Output<string | undefined>;
    /**
     * Create a Role resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: RoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Role resources.
 */
export interface RoleState {
    /**
     * Defines the role to switch to at login via [`SET ROLE`](https://www.postgresql.org/docs/current/sql-set-role.html).
     */
    assumeRole?: pulumi.Input<string>;
    /**
     * Defines whether a role bypasses every
     * row-level security (RLS) policy.  Default value is `false`.
     */
    bypassRowLevelSecurity?: pulumi.Input<boolean>;
    /**
     * If this role can log in, this specifies how
     * many concurrent connections the role can establish. `-1` (the default) means no
     * limit.
     */
    connectionLimit?: pulumi.Input<number>;
    /**
     * Defines a role's ability to execute `CREATE
     * DATABASE`.  Default value is `false`.
     */
    createDatabase?: pulumi.Input<boolean>;
    /**
     * Defines a role's ability to execute `CREATE ROLE`.
     * A role with this privilege can also alter and drop other roles.  Default value
     * is `false`.
     */
    createRole?: pulumi.Input<boolean>;
    /**
     * @deprecated Rename PostgreSQL role resource attribute "encrypted" to "encryptedPassword"
     */
    encrypted?: pulumi.Input<string>;
    /**
     * Defines whether the password is stored
     * encrypted in the system catalogs.  Default value is `true`.  NOTE: this value
     * is always set (to the conservative and safe value), but may interfere with the
     * behavior of
     * [PostgreSQL's `passwordEncryption` setting](https://www.postgresql.org/docs/current/static/runtime-config-connection.html#GUC-PASSWORD-ENCRYPTION).
     */
    encryptedPassword?: pulumi.Input<boolean>;
    /**
     * Terminate any session with an open transaction that has been idle for longer than the specified duration in milliseconds
     */
    idleInTransactionSessionTimeout?: pulumi.Input<number>;
    /**
     * Defines whether a role "inherits" the privileges of
     * roles it is a member of.  Default value is `true`.
     */
    inherit?: pulumi.Input<boolean>;
    /**
     * Defines whether role is allowed to log in.  Roles without
     * this attribute are useful for managing database privileges, but are not users
     * in the usual sense of the word.  Default value is `false`.
     */
    login?: pulumi.Input<boolean>;
    /**
     * The name of the role. Must be unique on the PostgreSQL
     * server instance where it is configured.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the role's password. A password is only of use
     * for roles having the `login` attribute set to true.
     */
    password?: pulumi.Input<string>;
    /**
     * Defines whether a role is allowed to initiate
     * streaming replication or put the system in and out of backup mode.  Default
     * value is `false`
     */
    replication?: pulumi.Input<boolean>;
    /**
     * Defines list of roles which will be granted to this new role.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Alters the search path of this new role. Note that
     * due to limitations in the implementation, values cannot contain the substring
     * `", "`.
     */
    searchPaths?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, the
     * [cleanup of ownership of objects](https://www.postgresql.org/docs/current/static/role-removal.html)
     * in each of the respective databases must occur before the ROLE can be dropped
     * from the catalog.  Set this option to true when there are multiple databases
     * in a PostgreSQL cluster using the same PostgreSQL ROLE for object ownership.
     * This is the third and final step taken when removing a ROLE from a database.
     */
    skipDropRole?: pulumi.Input<boolean>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, a
     * [`REASSIGN OWNED`](https://www.postgresql.org/docs/current/static/sql-reassign-owned.html) in
     * must be executed on each of the respective databases before the `DROP ROLE`
     * can be executed to dropped the ROLE from the catalog.  This is the first and
     * second steps taken when removing a ROLE from a database (the second step being
     * an implicit
     * [`DROP OWNED`](https://www.postgresql.org/docs/current/static/sql-drop-owned.html)).
     */
    skipReassignOwned?: pulumi.Input<boolean>;
    /**
     * Defines [`statementTimeout`](https://www.postgresql.org/docs/current/runtime-config-client.html#RUNTIME-CONFIG-CLIENT-STATEMENT) setting for this role which allows to abort any statement that takes more than the specified amount of time.
     */
    statementTimeout?: pulumi.Input<number>;
    /**
     * Defines whether the role is a "superuser", and
     * therefore can override all access restrictions within the database.  Default
     * value is `false`.
     */
    superuser?: pulumi.Input<boolean>;
    /**
     * Defines the date and time after which the role's
     * password is no longer valid.  Established connections past this `validTime`
     * will have to be manually terminated.  This value corresponds to a PostgreSQL
     * datetime. If omitted or the magic value `NULL` is used, `validUntil` will be
     * set to `infinity`.  Default is `NULL`, therefore `infinity`.
     */
    validUntil?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Role resource.
 */
export interface RoleArgs {
    /**
     * Defines the role to switch to at login via [`SET ROLE`](https://www.postgresql.org/docs/current/sql-set-role.html).
     */
    assumeRole?: pulumi.Input<string>;
    /**
     * Defines whether a role bypasses every
     * row-level security (RLS) policy.  Default value is `false`.
     */
    bypassRowLevelSecurity?: pulumi.Input<boolean>;
    /**
     * If this role can log in, this specifies how
     * many concurrent connections the role can establish. `-1` (the default) means no
     * limit.
     */
    connectionLimit?: pulumi.Input<number>;
    /**
     * Defines a role's ability to execute `CREATE
     * DATABASE`.  Default value is `false`.
     */
    createDatabase?: pulumi.Input<boolean>;
    /**
     * Defines a role's ability to execute `CREATE ROLE`.
     * A role with this privilege can also alter and drop other roles.  Default value
     * is `false`.
     */
    createRole?: pulumi.Input<boolean>;
    /**
     * @deprecated Rename PostgreSQL role resource attribute "encrypted" to "encryptedPassword"
     */
    encrypted?: pulumi.Input<string>;
    /**
     * Defines whether the password is stored
     * encrypted in the system catalogs.  Default value is `true`.  NOTE: this value
     * is always set (to the conservative and safe value), but may interfere with the
     * behavior of
     * [PostgreSQL's `passwordEncryption` setting](https://www.postgresql.org/docs/current/static/runtime-config-connection.html#GUC-PASSWORD-ENCRYPTION).
     */
    encryptedPassword?: pulumi.Input<boolean>;
    /**
     * Terminate any session with an open transaction that has been idle for longer than the specified duration in milliseconds
     */
    idleInTransactionSessionTimeout?: pulumi.Input<number>;
    /**
     * Defines whether a role "inherits" the privileges of
     * roles it is a member of.  Default value is `true`.
     */
    inherit?: pulumi.Input<boolean>;
    /**
     * Defines whether role is allowed to log in.  Roles without
     * this attribute are useful for managing database privileges, but are not users
     * in the usual sense of the word.  Default value is `false`.
     */
    login?: pulumi.Input<boolean>;
    /**
     * The name of the role. Must be unique on the PostgreSQL
     * server instance where it is configured.
     */
    name?: pulumi.Input<string>;
    /**
     * Sets the role's password. A password is only of use
     * for roles having the `login` attribute set to true.
     */
    password?: pulumi.Input<string>;
    /**
     * Defines whether a role is allowed to initiate
     * streaming replication or put the system in and out of backup mode.  Default
     * value is `false`
     */
    replication?: pulumi.Input<boolean>;
    /**
     * Defines list of roles which will be granted to this new role.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Alters the search path of this new role. Note that
     * due to limitations in the implementation, values cannot contain the substring
     * `", "`.
     */
    searchPaths?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, the
     * [cleanup of ownership of objects](https://www.postgresql.org/docs/current/static/role-removal.html)
     * in each of the respective databases must occur before the ROLE can be dropped
     * from the catalog.  Set this option to true when there are multiple databases
     * in a PostgreSQL cluster using the same PostgreSQL ROLE for object ownership.
     * This is the third and final step taken when removing a ROLE from a database.
     */
    skipDropRole?: pulumi.Input<boolean>;
    /**
     * When a PostgreSQL ROLE exists in multiple
     * databases and the ROLE is dropped, a
     * [`REASSIGN OWNED`](https://www.postgresql.org/docs/current/static/sql-reassign-owned.html) in
     * must be executed on each of the respective databases before the `DROP ROLE`
     * can be executed to dropped the ROLE from the catalog.  This is the first and
     * second steps taken when removing a ROLE from a database (the second step being
     * an implicit
     * [`DROP OWNED`](https://www.postgresql.org/docs/current/static/sql-drop-owned.html)).
     */
    skipReassignOwned?: pulumi.Input<boolean>;
    /**
     * Defines [`statementTimeout`](https://www.postgresql.org/docs/current/runtime-config-client.html#RUNTIME-CONFIG-CLIENT-STATEMENT) setting for this role which allows to abort any statement that takes more than the specified amount of time.
     */
    statementTimeout?: pulumi.Input<number>;
    /**
     * Defines whether the role is a "superuser", and
     * therefore can override all access restrictions within the database.  Default
     * value is `false`.
     */
    superuser?: pulumi.Input<boolean>;
    /**
     * Defines the date and time after which the role's
     * password is no longer valid.  Established connections past this `validTime`
     * will have to be manually terminated.  This value corresponds to a PostgreSQL
     * datetime. If omitted or the magic value `NULL` is used, `validUntil` will be
     * set to `infinity`.  Default is `NULL`, therefore `infinity`.
     */
    validUntil?: pulumi.Input<string>;
}
